@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: VariableProvider.java,v 1.8 2000/09/09 19:51:49 metlov Exp $
+ * $Id: VariableProvider.java,v 1.9 2000/11/12 14:59:34 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -180,7 +180,7 @@ public class VariableProvider implements gnu.jel.DVResolver {
     return new LongObject(v);
   };
 
-  public static gnu.jel.reflect.Float makeJELDoubleObject(float v) {
+  public static gnu.jel.reflect.Float makeJELFloatObject(float v) {
     return new FloatObject(v);
   };
 
@@ -191,102 +191,6 @@ public class VariableProvider implements gnu.jel.DVResolver {
 
 };
 
-class BooleanObject implements gnu.jel.reflect.Boolean {
-  boolean val;
-  
-  public BooleanObject(boolean val) {
-	this.val=val;
-  };
-  
-  public boolean getValue() {
-	return val;
-  };;    
-};
-
-class ByteObject implements gnu.jel.reflect.Byte {
-  byte val;
-  
-  public ByteObject(byte val) {
-	this.val=val;
-  };
-  
-  public byte getValue() {
-	return val;
-  };;    
-};
-
-class CharacterObject implements gnu.jel.reflect.Character {
-  char val;
-  
-  public CharacterObject(char val) {
-	this.val=val;
-  };
-  
-  public char getValue() {
-	return val;
-  };;    
-};
-
-
-class ShortObject implements gnu.jel.reflect.Short {
-  short val;
-  
-  public ShortObject(short val) {
-	this.val=val;
-  };
-  
-  public short getValue() {
-	return val;
-  };;    
-};
-
-class IntegerObject implements gnu.jel.reflect.Integer {
-  int val;
-  
-  public IntegerObject(int val) {
-	this.val=val;
-  };
-  
-  public int getValue() {
-	return val;
-  };;    
-};
-
-class LongObject implements gnu.jel.reflect.Long {
-  long val;
-  
-  public LongObject(long val) {
-	this.val=val;
-  };
-  
-  public long getValue() {
-	return val;
-  };;    
-};
-
-class FloatObject implements gnu.jel.reflect.Float {
-  float val;
-  
-  public FloatObject(float val) {
-	this.val=val;
-  };
-  
-  public float getValue() {
-	return val;
-  };;    
-};
-
-class DoubleObject implements gnu.jel.reflect.Double {
-  double val;
-  
-  public DoubleObject(double val) {
-	this.val=val;
-  };
-  
-  public double getValue() {
-	return val;
-  };;    
-};
 
 
 
