@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPunary.java,v 1.5 2000/09/09 19:51:48 metlov Exp $
+ * $Id: OPunary.java,v 1.6 2000/11/12 14:59:34 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -119,7 +119,7 @@ public class OPunary extends OPfunction {
 
     // set the result type
     resID=targetID;
-    resType=(targetID==8?targetClass:TypesStack.specialTypes[targetID]);
+    resType=(targetClass!=null?targetClass:TypesStack.specialTypes[targetID]);
 
     Class currClass=typesStk.peek();
     int   currID=typesStk.peekID();
