@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: TypesStack.java,v 1.4 2000/09/09 19:51:48 metlov Exp $
+ * $Id: TypesStack.java,v 1.5 2000/11/12 14:59:34 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -209,8 +209,12 @@ public class TypesStack implements Cloneable {
    * Pushes the class with given typeID into stack.
    */
   public final void pushID(int id,Class c) {
+    Debug.assert(! ((id==8) && (c==null)));
     typeIDs.push(id);
-    if (id==8) classes.push(c); else classes.push(specialTypes[id]);
+    if (c!=null) 
+      classes.push(c); 
+    else 
+      classes.push(specialTypes[id]);
     currWords+=stkoccup[baseType[id]];
     if (currWords>maxWords) maxWords=currWords;
   };
