@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: TestSuite.java,v 1.23 2000/09/10 15:59:34 metlov Exp $
+ * $Id: TestSuite.java,v 1.24 2000/11/12 14:59:34 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -384,6 +384,49 @@ public class TestSuite {
     testExpression("\"a\"+\"b\"+aarr[1][0]+\"c\"","ab3.0c", null, rtp, lib,o);
 
 
+    // Test case for a bug submitted by Dave Ekhaus
+    {
+      for(int i=0;i<8;i++) {
+        Class[] newDynamicLib=new Class[dynamicLib.length+1];
+        Object[] newRTP=new Object[rtp.length+1];
+        System.arraycopy(dynamicLib,0,newDynamicLib,0,dynamicLib.length);
+        System.arraycopy(rtp,0,newRTP,0,rtp.length);
+        switch(i) {
+        case 0:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELBooleanObject(false);
+          break;
+        case 1:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELByteObject((byte)55);
+          break;
+        case 2:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELCharacterObject(' ');
+          break;
+        case 3:
+          newRTP[newRTP.length-1]=
+            VariableProvider.makeJELShortObject((short)55);
+          break;
+        case 4:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELIntegerObject(55);
+          break;
+        case 5:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELLongObject(55);
+          break;
+        case 6:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELFloatObject(55);
+          break;
+        case 7:
+          newRTP[newRTP.length-1]=VariableProvider.makeJELDoubleObject(55);
+          break;
+        default:
+        };
+        newDynamicLib[newDynamicLib.length-1]=
+          newRTP[newRTP.length-1].getClass();
+        
+        Library lib1=new Library(staticLib,newDynamicLib,new Class[0],vp);
+        testExpression("aMethod", new Integer(1),null,newRTP,lib1,o);
+      };
+    };
+
     for(int k=0;k<2;k++) {
       o.println(); 
       o.println("----- THOROUGNLY TEST UNARY OPERATIONS  ------");
